Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(538)

Unified Diff: chrome/browser/background/background_application_list_model.h

Issue 10453101: Convert most of the rest of chrome to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/background/background_application_list_model.h
diff --git a/chrome/browser/background/background_application_list_model.h b/chrome/browser/background/background_application_list_model.h
index c4f6a45d19937247adc6dcafc5695b016176cd9c..f38a7676aaa77bad5b96f769a5312c66c0ae3014 100644
--- a/chrome/browser/background/background_application_list_model.h
+++ b/chrome/browser/background/background_application_list_model.h
@@ -17,6 +17,10 @@
class Profile;
+namespace gfx {
+class ImageSkia;
+}
+
// Model for list of Background Applications associated with a Profile (i.e.
// extensions with kBackgroundPermission set, or hosted apps with a
// BackgroundContents).
@@ -55,11 +59,11 @@ class BackgroundApplicationListModel : public content::NotificationObserver {
// that there is no icon associated with the extension, or that a pending
// task to retrieve the icon has not completed. See the Observer class above.
//
// NOTE: The model manages the SkBitmap result, that is it "owns" the memory,
// releasing it if the associated background application is unloaded.
// NOTE: All icons are currently sized as
// ExtensionIconSet::EXTENSION_ICON_BITTY.
- const SkBitmap* GetIcon(const extensions::Extension* extension);
+ const gfx::ImageSkia* GetIcon(const extensions::Extension* extension);
// Return the position of |extension| within this list model.
int GetPosition(const extensions::Extension* extension) const;
@@ -55,11 +59,11 @@ class BackgroundApplicationListModel : public content::NotificationObserver {
// task to retrieve the icon has not completed. See the Observer class above.
//
- // NOTE: The model manages the SkBitmap result, that is it "owns" the memory,
+ // NOTE: The model manages the ImageSkia result, that is it "owns" the memory,
// releasing it if the associated background application is unloaded.
// NOTE: All icons are currently sized as

Powered by Google App Engine
This is Rietveld 408576698